#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.3.0.0-DLHhc4fm2EtBrjeVir8DZb
key:                  hls-pragmas-plugin-2.3.0.0-DLHhc4fm2EtBrjeVir8DZb
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d65d142c0b8d50469012def11583070b
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-pragmas-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.3.0.0-DLHhc4fm2EtBrjeVir8DZb
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-8D2X0x8oD0MLkMWmsVnRML
    fuzzy-0.1.1.0-CWesCaxOqT1EkbNA5t7DPM ghc-9.6.6
    ghcide-2.3.0.0-Ld2sfCMfutFCRk4TbnbNXV
    hls-plugin-api-2.3.0.0-9QE7tvrsIC8JO1fH0MMC7Z
    lens-5.3.5-2HH8cODx6GtLPPzWDgzNV9
    lsp-2.2.0.0-1oFCwYFHfFVERkSoDoNvZN text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

